function [ kt ] = Stress_Step_Axial( Big_Dia, Small_Dia, Fillet )
%
%  This routine computes the stress concentration factor for an axial load
%  on a circular shaft with a diameter change.  Values are taken from
%  page 1028, Figure C-1 in Norton
%
%      Big_Dia = the larger diameter
%      Small_Dia = the smaller diameter
%      Fillet = the radius of the fillet at the step

Dt = [2.0 1.5 1.3 1.2 1.15 1.1 1.07 1.05 1.02 1.01]';
At = [1.01470 .99957 .99682 .96272 .98084 .98450 .98498 1.00480 1.01220 .98413]';
bt = [-.30035 -.28221 -.25751 -.25527 -.24485 -.20818 -.19548 -.17076 -.12474 -.10474]';

%  Compute the diameter ratio and then interpolate A and b from the tables

D = Big_Dia / Small_Dia;
A = interp1 (Dt, At, D);
b = interp1 (Dt, bt, D);

%  Compute the stress concentration factor

kt = A * (Fillet / Small_Dia) ^ b;

end

